/**
 * This file was heavily inspired by {@link https://github.com/lit/lit/tree/main/packages/labs/ssr} with some adjustments made.
 * Please see {@link ../ACKNOWLEDGEMENTS.md}
 */
/**
 * @beta
 */
export declare class Node extends EventTarget {
}
/**
 * @beta
 */
export declare class Element extends Node {
}
/**
 * @beta
 */
export declare class DOMTokenList {
    private element;
    private attributeName;
    private tokens;
    constructor(element: HTMLElement, attributeName: string);
    item(i: number): string | null;
    contains(token: string): number;
    indexOf(token: string): number;
    add(...tokens: string[]): void;
    remove(...tokens: string[]): void;
    toggle(token: string, force: boolean): boolean;
    replace(token: string, replacement: string): void;
    toString(): string;
    private updateClassName;
}
/**
 * @beta
 */
export declare abstract class HTMLElement extends Element {
    private static elementAttributes;
    private static getOrCreateAttributesForElement;
    private _shadowRoot;
    get attributes(): {
        name: string;
        value: string;
    }[];
    get shadowRoot(): ShadowRoot | null;
    get part(): DOMTokenList;
    get classList(): DOMTokenList;
    get className(): string | null;
    set className(value: string | null);
    abstract attributeChangedCallback?(name: string, old: string | null, value: string | null): void;
    setAttribute(name: string, value: string): void;
    removeAttribute(name: string): void;
    hasAttribute(name: string): boolean;
    attachShadow(init: ShadowRootInit): ShadowRoot;
    getAttribute(name: string): string | null;
}
/**
 * @beta
 */
export interface CustomHTMLElement {
    new (): HTMLElement;
    observedAttributes?: string[];
}
/**
 * @beta
 */
export declare class ShadowRoot {
}
/**
 * @beta
 */
export declare class Document extends Node {
    adoptedStyleSheets: ReadonlyArray<CSSStyleSheet>;
    createTreeWalker(): {};
    createTextNode(): {};
    createElement(): {};
    dispatchEvent(event: Event): boolean;
}
/**
 * @beta
 */
export declare class CustomEvent<T = any> extends Event {
    detail: T | null;
    constructor(type: string, init?: CustomEventInit<T>);
}
/**
 * @beta
 */
export declare class CSSStyleRule {
    selectorText: string | undefined;
    readonly style: CSSStyleDeclaration;
    get cssText(): string;
}
/**
 * @beta
 */
export declare class CSSStyleDeclaration {
    private rules;
    setProperty(name: string, value?: string): void;
    removeProperty(name: string): void;
    get cssText(): string;
}
/**
 * @beta
 */
export declare class CSSStyleSheet {
    replace(): void;
    readonly cssRules: CSSRule[];
    insertRule(rule: string, index?: number): number;
}
/**
 * @beta
 */
export declare type CustomElementRegistration = {
    ctor: {
        new (): HTMLElement;
    };
    observedAttributes: string[];
};
/**
 * @beta
 */
export declare class CustomElementRegistry {
    private __definitions;
    define(name: string, ctor: CustomHTMLElement): void;
    get(name: string): (new () => HTMLElement) | undefined;
}
/**
 * @beta
 */
export declare class MutationObserver {
    observe(): void;
}
/**
 * Shim of MediaQueryList.
 * {@link https://developer.mozilla.org/en-US/docs/Web/API/MediaQueryList} */
export declare class MediaQueryList {
    /** No-op */
    addEventListener(): void;
    /** Always false */
    matches: boolean;
}
/**
 * @beta
 */
export declare class Window extends EventTarget {
    Node: typeof Node;
    Element: typeof Element;
    HTMLElement: typeof HTMLElement;
    Document: typeof Document;
    CustomEvent: typeof CustomEvent;
    CSSStyleSheet: typeof CSSStyleSheet;
    CSSStyleDeclaration: typeof CSSStyleDeclaration;
    CSSStyleRule: typeof CSSStyleRule;
    ShadowRoot: typeof ShadowRoot;
    CustomElementRegistry: typeof CustomElementRegistry;
    MutationObserver: typeof MutationObserver;
    MediaQueryList: typeof MediaQueryList;
    matchMedia: () => MediaQueryList;
    window: unknown;
    document: unknown;
    customElements: unknown;
    dispatchEvent: any;
    addEventListener: any;
    removeEventListener: any;
    constructor(props?: Record<string, any>);
}
/**
 * Creates a window object.
 * @param props - Additional properties to expose on the window.
 *
 * @beta
 */
export declare function createWindow<T extends Record<string, any>>(props?: T): Window & T;
/**
 * Installs a window object on the global, exposing properties directly on globalThis and globalthis.window
 * @param window - The Window object to install
 *
 * @beta
 */
export declare function installWindowOnGlobal(window: Record<string, any>): void;
