import { RenderInfo } from "../render-info.js";
import { AttributesMap, ElementRenderer } from "./interfaces.js";
export declare const getElementRenderer: (renderInfo: RenderInfo, tagName: string, ceClass?: typeof HTMLElement | undefined, attributes?: AttributesMap) => ElementRenderer;
/**
 * @beta
 */
export declare abstract class DefaultElementRenderer implements Omit<ElementRenderer, "renderShadow" | "renderAttributes"> {
    readonly tagName: string;
    private readonly renderInfo?;
    private parent;
    abstract readonly element?: HTMLElement;
    elementChanged(): void;
    /**
     * Should return true when the renderer should handle rendering for a custom element ctor or tag name.
     * @param ctor - the custom element class
     * @param tagName - the custom element tag name
     * @param attributes - the attribute map
     * @returns
     */
    static matchesClass(ctor: typeof HTMLElement, tagName: string, attributes: AttributesMap): boolean;
    constructor(tagName: string, renderInfo?: RenderInfo | undefined);
    abstract connectedCallback(): void;
    abstract attributeChangedCallback(name: string, prev: string | null, next: string | null): void;
    dispatchEvent(event: Event): boolean;
    /**
     * Sets a property for the element if it exists.
     */
    setProperty(name: string, value: unknown): void;
    /**
     * Sets an attribute for the element if it exists.
     */
    setAttribute(name: string, value: string): void;
}
