import { FASTElement } from "@microsoft/fast-element";
import { RenderInfo } from "../render-info.js";
import { StyleRenderer } from "../styles/style-renderer.js";
import { DefaultTemplateRenderer } from "../template-renderer/template-renderer.js";
import { DefaultElementRenderer } from "./element-renderer.js";
import { AsyncElementRenderer, AttributesMap, ElementRenderer } from "./interfaces.js";
/**
 * An {@link ElementRenderer} implementation designed to render components
 * built with FAST.
 *
 */
declare abstract class FASTElementRenderer extends DefaultElementRenderer {
    /**
     * The element instance represented by the {@link FASTElementRenderer}.
     */
    readonly element: FASTElement;
    /**
     * When true, instructs the ElementRenderer to yield the `defer-hydration` attribute for
     * rendered elements.
     */
    protected abstract deferHydration: boolean;
    /**
     * The template renderer to use when rendering a component template
     */
    protected abstract templateRenderer: DefaultTemplateRenderer;
    /**
     * Responsible for rendering stylesheets
     */
    protected abstract styleRenderer: StyleRenderer;
    static matchesClass(ctor: typeof HTMLElement, tagName: string, attributes: AttributesMap): boolean;
    /**
     * Indicate to the {@link FASTElementRenderer} that the instance should execute DOM connection behavior.
     */
    connectedCallback(): void;
    /**
     * Indicate to the {@link FASTElementRenderer} that an attribute has been changed.
     * @param name - The name of the changed attribute
     * @param old - The old attribute value
     * @param value - The new attribute value
     */
    attributeChangedCallback(name: string, old: string | null, value: string | null): void;
    /**
     * Constructs a new {@link FASTElementRenderer}.
     * @param tagName - the tag-name of the element to create.
     */
    constructor(tagName: string, renderInfo: RenderInfo);
}
export declare abstract class SyncFASTElementRenderer extends FASTElementRenderer implements ElementRenderer {
    renderAttributes: typeof renderAttributesSync;
    renderShadow: typeof renderShadow;
}
export declare abstract class AsyncFASTElementRenderer extends FASTElementRenderer implements AsyncElementRenderer {
    constructor(tagName: string, renderInfo: RenderInfo);
    renderAttributes(this: AsyncFASTElementRenderer): IterableIterator<string | Promise<string>>;
    renderShadow: (renderInfo: RenderInfo) => IterableIterator<string | Promise<string>>;
    private pauseRendering;
    private awaiting;
    private pendingTaskHandler;
}
declare function renderAttributesSync(this: FASTElementRenderer): IterableIterator<string>;
declare function renderShadow(this: FASTElementRenderer, renderInfo: RenderInfo): IterableIterator<string>;
export {};
