import { AsyncFASTElementRenderer, SyncFASTElementRenderer } from "./element-renderer/fast-element-renderer.js";
import { AsyncElementRenderer, ConstructableElementRenderer, ConstructableFASTElementRenderer, ElementRenderer } from "./element-renderer/interfaces.js";
import { RenderInfo } from "./render-info.js";
import { StyleRenderer } from "./styles/style-renderer.js";
import { ViewBehaviorFactoryRenderer } from "./template-renderer/directives.js";
import { AsyncTemplateRenderer, TemplateRenderer } from "./template-renderer/template-renderer.js";
import "./configure-fast-element.js";
/**
 * Configuration for SSR factory.
 * @beta
 */
export interface SSRConfiguration {
    /**
     * When 'async', configures the renderer to support async rendering.
     * 'async' rendering will yield 'string | Promise<string>'
     *
     * Defaults to 'sync'.
     */
    renderMode?: "sync" | "async";
    /**
     * Configures the renderer to yield the `defer-hydration` attribute during element rendering.
     * The `defer-hydration` attribute can be used to prevent immediate hydration of the element
     * by fast-element by importing hydration support in the client bundle.
     *
     * Defaults to `false`
     * @example
     *
     * ```ts
     * import "@microsoft/fast-element/install-element-hydration";
     * ```
     */
    deferHydration?: boolean;
    /**
     * Renderers for author-defined ViewBehaviorFactories.
     */
    viewBehaviorFactoryRenderers?: ViewBehaviorFactoryRenderer<any>[];
}
/** @beta */
declare function fastSSR(): {
    templateRenderer: TemplateRenderer;
    ElementRenderer: ConstructableFASTElementRenderer<SyncFASTElementRenderer>;
};
declare function fastSSR(config: Omit<SSRConfiguration, "renderMode">): {
    templateRenderer: TemplateRenderer;
    ElementRenderer: ConstructableFASTElementRenderer<SyncFASTElementRenderer>;
};
/** @beta */
declare function fastSSR(config: SSRConfiguration & Record<"renderMode", "sync">): {
    templateRenderer: TemplateRenderer;
    ElementRenderer: ConstructableFASTElementRenderer<SyncFASTElementRenderer>;
};
/** @beta */
declare function fastSSR(config: SSRConfiguration & Record<"renderMode", "async">): {
    templateRenderer: AsyncTemplateRenderer;
    ElementRenderer: ConstructableFASTElementRenderer<AsyncFASTElementRenderer>;
};
export default fastSSR;
export * from "./declarative-shadow-dom-polyfill.js";
export * from "./request-storage.js";
export type { ElementRenderer, AsyncElementRenderer, StyleRenderer, TemplateRenderer, AsyncTemplateRenderer, ViewBehaviorFactoryRenderer, RenderInfo, ConstructableElementRenderer, ConstructableFASTElementRenderer, };
