import { Binding, ViewBehaviorFactory } from "@microsoft/fast-element";
/**
 * Allows fast identification of operation types
 */
export declare const enum OpType {
    customElementOpen = 0,
    customElementClose = 1,
    customElementAttributes = 2,
    customElementShadow = 3,
    attributeBinding = 4,
    viewBehaviorFactory = 5,
    templateElementOpen = 6,
    templateElementClose = 7,
    text = 8
}
/**
 * Operation to emit static text
 */
export declare type TextOp = {
    type: OpType.text;
    value: string;
};
/**
 * Operation to open a custom element
 */
export declare type CustomElementOpenOp = {
    type: OpType.customElementOpen;
    /**
     * The tagname of the custom element
     */
    tagName: string;
    /**
     * The constructor of the custom element
     */
    ctor: typeof HTMLElement;
    /**
     * Attributes of the custom element, non-inclusive of any attributes
     * that are the product of bindings
     */
    staticAttributes: Map<string, string>;
};
/**
 * Operation to close a custom element
 */
export declare type CustomElementCloseOp = {
    type: OpType.customElementClose;
};
export declare type CustomElementShadowOp = {
    type: OpType.customElementShadow;
};
/**
 * Operation to emit static text
 */
export declare type ViewBehaviorFactoryOp = {
    type: OpType.viewBehaviorFactory;
    factory: ViewBehaviorFactory;
};
/**
 * Operation to emit a bound attribute
 */
export declare type AttributeBindingOp = {
    type: OpType.attributeBinding;
    dataBinding: Binding;
    target: string;
    aspect: number;
    useCustomElementInstance: boolean;
};
/**
 * Operation to emit a template element open tag
 */
export declare type TemplateElementOpenOp = {
    type: OpType.templateElementOpen;
    staticAttributes: Map<string, string>;
    dynamicAttributes: AttributeBindingOp[];
};
/**
 * Operation to emit a template element closing tag
 */
export declare type TemplateElementCloseOp = {
    type: OpType.templateElementClose;
};
/**
 * Operation to emit to custom-element attributes
 */
export declare type CustomElementAttributes = {
    type: OpType.customElementAttributes;
};
export declare type Op = AttributeBindingOp | CustomElementOpenOp | CustomElementCloseOp | ViewBehaviorFactoryOp | CustomElementAttributes | CustomElementShadowOp | TemplateElementOpenOp | TemplateElementCloseOp | TextOp;
