import { ChildrenDirective, Constructable, ExecutionContext, RefDirective, RepeatDirective, SlottedDirective, ViewBehaviorFactory } from "@microsoft/fast-element";
import { RenderDirective } from "@microsoft/fast-element/render.js";
import { RenderInfo } from "../render-info.js";
import { DefaultTemplateRenderer } from "./template-renderer.js";
/**
 * Describes an implementation that can render a directive.
 *
 * @beta
 */
export interface ViewBehaviorFactoryRenderer<T extends ViewBehaviorFactory> {
    /**
     * Renders a ViewBehaviorFactory
     * @param behaviorFactory - The ViewBehaviorFactory instance to render
     * @param renderInfo - The current RenderInfo context
     * @param source - Source data
     * @param renderer - The TemplateRenderer
     * @param context - The ExecutionContext
     */
    render(behaviorFactory: T, renderInfo: RenderInfo, source: any, renderer: DefaultTemplateRenderer, context: ExecutionContext): IterableIterator<string>;
    /**
     * The behavior constructor to use this renderer for.
     */
    matcher: Constructable<T>;
}
export declare const RepeatDirectiveRenderer: ViewBehaviorFactoryRenderer<RepeatDirective>;
export declare const RenderDirectiveRenderer: ViewBehaviorFactoryRenderer<RenderDirective>;
export declare const ChildrenDirectiveRenderer: ViewBehaviorFactoryRenderer<ChildrenDirective>;
export declare const RefDirectiveRenderer: ViewBehaviorFactoryRenderer<RefDirective>;
export declare const SlottedDirectiveRenderer: ViewBehaviorFactoryRenderer<SlottedDirective>;
export declare const defaultViewBehaviorFactoryRenderers: ViewBehaviorFactoryRenderer<any>[];
