import { __classPrivateFieldGet } from "tslib";
import { FASTElement, FASTElementDefinition } from "@microsoft/fast-element";
import { AsyncFASTElementRenderer, SyncFASTElementRenderer, } from "./element-renderer/fast-element-renderer.js";
import { StyleElementStyleRenderer } from "./styles/style-renderer.js";
import { defaultViewBehaviorFactoryRenderers, } from "./template-renderer/directives.js";
import { DefaultTemplateRenderer, } from "./template-renderer/template-renderer.js";
// Perform necessary configuration of FAST-Element library
// for rendering in NodeJS
import "./configure-fast-element.js";
/**
 * Factory for creating SSR rendering assets.
 * @example
 * ```ts
 * import "@microsoft/install-dom-shim";
 * import fastSSR from "@microsoft/fast-ssr";
 * import { html } from "@microsoft/fast-element";
 * const { templateRenderer } = fastSSR();
 *
 * const streamableSSRResult = templateRenderer.render(html`...`);
 * ```
 *
 * @beta
 */
function fastSSR(config) {
    var _a, _disabledConstructors;
    config = Object.assign({ renderMode: "sync", deferHydration: false }, config);
    const templateRenderer = new DefaultTemplateRenderer();
    const elementRenderer = (_a = class extends (config.renderMode !== "async"
            ? SyncFASTElementRenderer
            : AsyncFASTElementRenderer) {
            constructor() {
                super(...arguments);
                this.templateRenderer = templateRenderer;
                this.styleRenderer = new StyleElementStyleRenderer();
                this.deferHydration = config === null || config === void 0 ? void 0 : config.deferHydration;
            }
            static matchesClass(ctor, tagName, attributes) {
                const canRender = ctor.prototype instanceof FASTElement;
                if (!canRender) {
                    return false;
                }
                const disabled = __classPrivateFieldGet(elementRenderer, _a, "f", _disabledConstructors);
                return !(disabled.has(tagName) || disabled.has(ctor));
            }
            static disable(...elements) {
                for (const element of elements) {
                    __classPrivateFieldGet(elementRenderer, _a, "f", _disabledConstructors).add(element instanceof FASTElementDefinition ? element.type : element);
                }
            }
        },
        _disabledConstructors = { value: new Set() },
        _a);
    templateRenderer.withDefaultElementRenderers(elementRenderer);
    // Configure out-of-box ViewBehaviorFactory renderers first
    templateRenderer.withViewBehaviorFactoryRenderers(...defaultViewBehaviorFactoryRenderers);
    // Add any author-defined ViewBehaviorFactories. This order allows overriding
    // out-of-box renderers.
    if (Array.isArray(config.viewBehaviorFactoryRenderers)) {
        templateRenderer.withViewBehaviorFactoryRenderers(...config.viewBehaviorFactoryRenderers);
    }
    return {
        templateRenderer,
        ElementRenderer: elementRenderer,
    };
}
export default fastSSR;
export * from "./declarative-shadow-dom-polyfill.js";
export * from "./request-storage.js";
