import { __awaiter } from "tslib";
import { expect, test } from "@playwright/test";
test("Check that the first element has styles assigned", ({ page }) => __awaiter(void 0, void 0, void 0, function* () {
    yield page.goto("/fast-style");
    const cards = page.locator("fast-card");
    const styles = yield cards.evaluateAll((cardList) => {
        return cardList.map((card) => {
            return window.getComputedStyle(card, null).getPropertyValue("background-color");
        });
    });
    expect(styles[0]).toEqual("rgb(26, 26, 26)");
}));
test("Check that the nested element in the first element has styles assigned", ({ page }) => __awaiter(void 0, void 0, void 0, function* () {
    yield page.goto("/fast-style");
    const cards = page.locator("fast-card");
    const styles = yield cards.evaluateAll((cardList) => {
        return cardList.map((card) => {
            var _a;
            return window.getComputedStyle((_a = card.shadowRoot) === null || _a === void 0 ? void 0 : _a.querySelector("fast-button"), null).getPropertyValue("background-color");
        });
    });
    expect(styles[0]).toEqual("rgb(43, 43, 43)");
}));
test("Check that all elements have styles assigned", ({ page }) => __awaiter(void 0, void 0, void 0, function* () {
    yield page.goto("/fast-style");
    const cards = page.locator("fast-card");
    const styles = yield cards.evaluateAll((cardList) => {
        return cardList.map((card) => {
            return window.getComputedStyle(card, null).getPropertyValue("background-color");
        });
    });
    expect(styles).toHaveLength(10);
    styles.forEach((style) => {
        expect(style).toEqual("rgb(26, 26, 26)");
    });
}));
test("Check that all nested elements have styles assigned", ({ page }) => __awaiter(void 0, void 0, void 0, function* () {
    yield page.goto("/fast-style");
    const cards = page.locator("fast-card");
    const styles = yield cards.evaluateAll((cardList) => {
        return cardList.map((card) => {
            var _a;
            return window.getComputedStyle((_a = card.shadowRoot) === null || _a === void 0 ? void 0 : _a.querySelector("fast-button"), null).getPropertyValue("background-color");
        });
    });
    expect(styles).toHaveLength(10);
    styles.forEach((style) => {
        expect(style).toEqual("rgb(43, 43, 43)");
    });
}));
