import { fastStyleTagName } from "./fast-style.js";
function collectStyles(style) {
    let content = "";
    if (typeof style === "string") {
        content = style;
    }
    else if (style instanceof CSSStyleSheet) {
        const rules = style.cssRules;
        for (let i = 0, length = rules.length; i < length; i++) {
            content += rules[i].cssText;
        }
    }
    else {
        for (const s of style.styles) {
            content += collectStyles(s);
        }
    }
    return content;
}
export class FASTStyleStyleRenderer {
    render(styles) {
        let id = FASTStyleStyleRenderer.stylesheetCache.get(styles);
        const content = id === undefined ? collectStyles(styles) : null;
        let contentAttr = "";
        if (content !== null) {
            id = FASTStyleStyleRenderer.nextId();
            FASTStyleStyleRenderer.stylesheetCache.set(styles, id);
            contentAttr = `css="${content}"`;
        }
        return `<${fastStyleTagName} style-id="${id}" ${contentAttr}></${fastStyleTagName}>`;
    }
}
FASTStyleStyleRenderer.stylesheetCache = new Map();
FASTStyleStyleRenderer.nextId = (() => {
    let id = 0;
    const prefix = "fast-style";
    return () => `${prefix}-${id++}`;
})();
export class StyleElementStyleRenderer {
    render(styles) {
        return `<style>${collectStyles(styles)}</style>`;
    }
}
