const sheetsForTarget = new WeakMap();
function getOrCreateFor(target) {
    let set = sheetsForTarget.get(target);
    if (set) {
        return set;
    }
    set = new Set();
    sheetsForTarget.set(target, set);
    return set;
}
export class FASTSSRStyleStrategy {
    constructor(styles) {
        this.styles = styles;
    }
    addStylesTo(target) {
        const cache = getOrCreateFor(target);
        this.styles.forEach(style => cache === null || cache === void 0 ? void 0 : cache.add(style));
    }
    removeStylesFrom(target) {
        const cache = getOrCreateFor(target);
        this.styles.forEach(style => cache === null || cache === void 0 ? void 0 : cache.delete(style));
    }
    static getStylesFor(target) {
        return sheetsForTarget.get(target) || null;
    }
}
