import { ChildrenDirective, RefDirective, RepeatDirective, SlottedDirective, ViewTemplate, } from "@microsoft/fast-element";
import { RenderDirective } from "@microsoft/fast-element/render.js";
export const RepeatDirectiveRenderer = Object.freeze({
    matcher: RepeatDirective,
    *render(directive, renderInfo, source, renderer, context) {
        const items = directive.dataBinding.evaluate(source, context);
        const template = directive.templateBinding.evaluate(source, context);
        const childContext = Object.create(context, {
            parent: { value: source },
            parentContext: { value: context },
        });
        if (template instanceof ViewTemplate) {
            if (directive.options.positioning) {
                for (let i = 0, length = items.length; i < length; i++) {
                    childContext.index = i;
                    childContext.length = length;
                    yield* renderer.render(template, renderInfo, items[i], childContext);
                }
            }
            else {
                for (let i = 0, length = items.length; i < length; i++) {
                    yield* renderer.render(template, renderInfo, items[i], childContext);
                }
            }
        }
        else {
            throw new Error("Unable to render Repeat Directive template");
        }
    },
});
export const RenderDirectiveRenderer = Object.freeze({
    matcher: RenderDirective,
    *render(directive, renderInfo, source, renderer, context) {
        const data = directive.dataBinding.evaluate(source, context);
        const template = directive.templateBinding.evaluate(source, context);
        const childContext = Object.create(context, {
            parent: { value: source },
            parentContext: { value: context },
        });
        if (template instanceof ViewTemplate) {
            yield* renderer.render(template, renderInfo, data, childContext);
        }
        else {
            throw new Error("Unable to render Render Directive template");
        }
    },
});
function* noop() {
    yield "";
}
export const ChildrenDirectiveRenderer = Object.freeze({
    matcher: ChildrenDirective,
    render: noop,
});
export const RefDirectiveRenderer = Object.freeze({
    matcher: RefDirective,
    render: noop,
});
export const SlottedDirectiveRenderer = Object.freeze({
    matcher: SlottedDirective,
    render: noop,
});
export const defaultViewBehaviorFactoryRenderers = [
    RepeatDirectiveRenderer,
    RenderDirectiveRenderer,
    ChildrenDirectiveRenderer,
    RefDirectiveRenderer,
    SlottedDirectiveRenderer,
];
