import { parseStringToOpCodes } from "./template-parser/template-parser.js";
/**
 * SSR implementation of {@link @microsoft/fast-element#HTMLView}. Due to
 * drastic type difference requirements, it does not extend it directly. Most
 * methods are no-op. SSR op-codes are created during construction to be used
 * by the ElementRenderer.
 */
export class SSRView {
    constructor(html, factories) {
        this.result = null;
        this.html = html;
        this.factories = factories;
        const codes = parseStringToOpCodes(html, factories, true);
        /**
         * If the first and last codes are template elements, populate static
         * and dynamic attributes for the host element and remove those op codes.
         */
        if (codes.length) {
            const firstCode = codes[0];
            if (firstCode.type === 6 /* OpType.templateElementOpen */ &&
                codes[codes.length - 1].type === 7 /* OpType.templateElementClose */) {
                if (firstCode.staticAttributes.size) {
                    this.hostStaticAttributes = firstCode.staticAttributes;
                }
                if (firstCode.dynamicAttributes.length) {
                    this.hostDynamicAttributes = firstCode.dynamicAttributes;
                }
                codes.shift();
                codes.pop();
            }
        }
        this.codes = codes;
    }
    createView() {
        return this;
    }
    bind() { }
    unbind() { }
    appendTo() { }
    static isSSRView(view) {
        return view instanceof SSRView;
    }
}
